==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/search/all_16.js <==
var searchData=
[
  ['what',['what',['../classviennacl_1_1device__specific_1_1generator__not__supported__exception.html#a81466e1e8d6d32902c9dc06b224e7682',1,'viennacl::device_specific::generator_not_supported_exception::what()'],['../classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#ab3a32adb953850e788d550006680a25a',1,'viennacl::device_specific::template_base::invalid_template_exception::what()'],['../classviennacl_1_1memory__exception.html#a2bd16efb8a50540d155c6eb81d5d45e4',1,'viennacl::memory_exception::what()'],['../classviennacl_1_1cuda__not__available__exception.html#a94c488fd1c10322c3f594bdf7946a859',1,'viennacl::cuda_not_available_exception::what()'],['../classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a878174e36fef97bbdc14689561f540e2',1,'viennacl::scheduler::statement_not_supported_exception::what()']]],
  ['with_5fstride_5fand_5frange',['with_stride_and_range',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a9b1070f298901e5077817c8939cb67f2',1,'viennacl::linalg::opencl::kernels::ambm_config::with_stride_and_range()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a9fac42b00a34a2fd36ab92e90bedabf7',1,'viennacl::linalg::opencl::kernels::asbs_config::with_stride_and_range()']]],
  ['wrap_2dhost_2dbuffer_2ecpp',['wrap-host-buffer.cpp',['../wrap-host-buffer_8cpp.html',1,'']]],
  ['write_5fhouseholder_5fto_5fa',['write_householder_to_A',['../namespaceviennacl_1_1linalg_1_1detail.html#a0ff42f36e98db6c181b16c78f76f0fdb',1,'viennacl::linalg::detail']]],
  ['write_5fhouseholder_5fto_5fa_5fublas',['write_householder_to_A_ublas',['../namespaceviennacl_1_1linalg_1_1detail.html#a0481a094460753dd7fb519c9dda3bdc1',1,'viennacl::linalg::detail']]],
  ['write_5fhouseholder_5fto_5fa_5fviennacl',['write_householder_to_A_viennacl',['../namespaceviennacl_1_1linalg_1_1detail.html#ae04154f304cceaa81ae1fc24882fd7ba',1,'viennacl::linalg::detail']]],
  ['write_5fmatrix_5fmarket_5ffile',['write_matrix_market_file',['../namespaceviennacl_1_1io.html#aa5412349a849ee0f9e68e2f93e0af987',1,'viennacl::io::write_matrix_market_file(std::vector&lt; std::map&lt; unsigned int, ScalarT &gt; &gt; const &amp;mat, const char *file, long index_base=1)'],['../namespaceviennacl_1_1io.html#afcf964aa43d02df697f48209aaf0d8fd',1,'viennacl::io::write_matrix_market_file(std::vector&lt; std::map&lt; unsigned int, ScalarT &gt; &gt; const &amp;mat, const std::string &amp;file, long index_base=1)'],['../namespaceviennacl_1_1io.html#a6b2fd79d7ec50b0c4ae3d858a843a693',1,'viennacl::io::write_matrix_market_file(MatrixT const &amp;mat, const std::string &amp;file, long index_base=1)']]],
  ['write_5fmatrix_5fmarket_5ffile_5fimpl',['write_matrix_market_file_impl',['../namespaceviennacl_1_1io.html#aceb24cd9d27f0def009a5b0e41c31021',1,'viennacl::io']]],
  ['write_5fset_5fto_5farray',['write_set_to_array',['../namespaceviennacl_1_1linalg_1_1detail_1_1spai.html#a511597723c2d451fda55ff4ead99eaf0',1,'viennacl::linalg::detail::spai']]],
  ['write_5fto_5fblock',['write_to_block',['../namespaceviennacl_1_1linalg_1_1detail_1_1spai.html#a65295176395fdf1c526d3880f3d76b53',1,'viennacl::linalg::detail::spai']]],
  ['writetogmem',['writeToGmem',['../namespaceviennacl_1_1linalg_1_1cuda.html#a743caf7cf9f215b2b075263e4db8ee21',1,'viennacl::linalg::cuda']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/all_16.js <==
var searchData=
[
  ['what',['what',['../classviennacl_1_1device__specific_1_1generator__not__supported__exception.html#a81466e1e8d6d32902c9dc06b224e7682',1,'viennacl::device_specific::generator_not_supported_exception::what()'],['../classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html#ab3a32adb953850e788d550006680a25a',1,'viennacl::device_specific::template_base::invalid_template_exception::what()'],['../classviennacl_1_1memory__exception.html#a2bd16efb8a50540d155c6eb81d5d45e4',1,'viennacl::memory_exception::what()'],['../classviennacl_1_1cuda__not__available__exception.html#a94c488fd1c10322c3f594bdf7946a859',1,'viennacl::cuda_not_available_exception::what()'],['../classviennacl_1_1scheduler_1_1statement__not__supported__exception.html#a878174e36fef97bbdc14689561f540e2',1,'viennacl::scheduler::statement_not_supported_exception::what()']]],
  ['with_5fstride_5fand_5frange',['with_stride_and_range',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a9b1070f298901e5077817c8939cb67f2',1,'viennacl::linalg::opencl::kernels::ambm_config::with_stride_and_range()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a9fac42b00a34a2fd36ab92e90bedabf7',1,'viennacl::linalg::opencl::kernels::asbs_config::with_stride_and_range()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1avbv__config.html#acefa33d4a640c0e597b1edbdbb7aa919',1,'viennacl::linalg::opencl::kernels::avbv_config::with_stride_and_range()']]],
  ['wrap_2dhost_2dbuffer_2ecpp',['wrap-host-buffer.cpp',['../wrap-host-buffer_8cpp.html',1,'']]],
  ['write_5fhouseholder_5fto_5fa',['write_householder_to_A',['../namespaceviennacl_1_1linalg_1_1detail.html#a0ff42f36e98db6c181b16c78f76f0fdb',1,'viennacl::linalg::detail']]],
  ['write_5fhouseholder_5fto_5fa_5fublas',['write_householder_to_A_ublas',['../namespaceviennacl_1_1linalg_1_1detail.html#a0481a094460753dd7fb519c9dda3bdc1',1,'viennacl::linalg::detail']]],
  ['write_5fhouseholder_5fto_5fa_5fviennacl',['write_householder_to_A_viennacl',['../namespaceviennacl_1_1linalg_1_1detail.html#ae04154f304cceaa81ae1fc24882fd7ba',1,'viennacl::linalg::detail']]],
  ['write_5fmatrix_5fmarket_5ffile',['write_matrix_market_file',['../namespaceviennacl_1_1io.html#aa5412349a849ee0f9e68e2f93e0af987',1,'viennacl::io::write_matrix_market_file(std::vector&lt; std::map&lt; unsigned int, ScalarT &gt; &gt; const &amp;mat, const char *file, long index_base=1)'],['../namespaceviennacl_1_1io.html#afcf964aa43d02df697f48209aaf0d8fd',1,'viennacl::io::write_matrix_market_file(std::vector&lt; std::map&lt; unsigned int, ScalarT &gt; &gt; const &amp;mat, const std::string &amp;file, long index_base=1)'],['../namespaceviennacl_1_1io.html#a6b2fd79d7ec50b0c4ae3d858a843a693',1,'viennacl::io::write_matrix_market_file(MatrixT const &amp;mat, const std::string &amp;file, long index_base=1)']]],
  ['write_5fmatrix_5fmarket_5ffile_5fimpl',['write_matrix_market_file_impl',['../namespaceviennacl_1_1io.html#aceb24cd9d27f0def009a5b0e41c31021',1,'viennacl::io']]],
  ['write_5fset_5fto_5farray',['write_set_to_array',['../namespaceviennacl_1_1linalg_1_1detail_1_1spai.html#a511597723c2d451fda55ff4ead99eaf0',1,'viennacl::linalg::detail::spai']]],
  ['write_5fto_5fblock',['write_to_block',['../namespaceviennacl_1_1linalg_1_1detail_1_1spai.html#a65295176395fdf1c526d3880f3d76b53',1,'viennacl::linalg::detail::spai']]],
  ['writetogmem',['writeToGmem',['../namespaceviennacl_1_1linalg_1_1cuda.html#a743caf7cf9f215b2b075263e4db8ee21',1,'viennacl::linalg::cuda']]]
];
